==> http-client-js-0.3.0.tgz: package/test/scenarios/operation-parameters/with_body_property.md <==
# Should emit an operation that has a @body explicitly set.

```tsp
@service
namespace Test;

model Widget {
  id: string;
  name: string;
  age?: string;
}

@post op create(@body widget: Widget, @header foo?: string): void;
```

## Operation

The operation has has no required parameters so options and client should be the only ones in the signature

```ts src/api/testClientOperations.ts function create
export async function create(
  client: TestClientContext,
  widget: Widget,
  options?: CreateOptions,
): Promise<void> {
  const path = parse("/").expand({});
  const httpRequestOptions = {
    headers: {
      ...(options?.foo && { foo: options?.foo }),
    },
    body: jsonWidgetToTransportTransform(widget),
  };
  const response = await client.pathUnchecked(path).post(httpRequestOptions);

  if (typeof options?.operationOptions?.onResponse === "function") {
    options?.operationOptions?.onResponse(response);
  }
  if (+response.status === 204 && !response.body) {
    return;
  }
  throw createRestError(response);
}
```

## Options

The options bag should like all the optional parameters of the operation

```ts src/api/testClientOperations.ts interface CreateOptions
export interface CreateOptions extends OperationOptions {
  foo?: string;
}
```

## Client

```ts src/testClient.ts class TestClient
export class TestClient {
  #context: TestClientContext;

  constructor(endpoint: string, options?: TestClientOptions) {
    this.#context = createTestClientContext(endpoint, options);
  }
  async create(widget: Widget, options?: CreateOptions) {
    return create(this.#context, widget, options);
  }
}
```

==> http-client-js-0.4.0.tgz: package/test/scenarios/operation-parameters/with_body_property.md <==
# Should emit an operation that has a @body explicitly set.

```tsp
@service
namespace Test;

model Widget {
  id: string;
  name: string;
  age?: string;
}

@post op create(@body widget: Widget, @header foo?: string): void;
```

## Operation

The operation has has no required parameters so options and client should be the only ones in the signature

```ts src/api/testClientOperations.ts function create
export async function create(
  client: TestClientContext,
  widget: Widget,
  options?: CreateOptions,
): Promise<void> {
  const path = parse("/").expand({});
  const httpRequestOptions = {
    headers: {
      ...(options?.foo && { foo: options.foo }),
    },
    body: jsonWidgetToTransportTransform(widget),
  };
  const response = await client.pathUnchecked(path).post(httpRequestOptions);

  if (typeof options?.operationOptions?.onResponse === "function") {
    options?.operationOptions?.onResponse(response);
  }
  if (+response.status === 204 && !response.body) {
    return;
  }
  throw createRestError(response);
}
```

## Options

The options bag should like all the optional parameters of the operation

```ts src/api/testClientOperations.ts interface CreateOptions
export interface CreateOptions extends OperationOptions {
  foo?: string;
}
```

## Client

```ts src/testClient.ts class TestClient
export class TestClient {
  #context: TestClientContext;

  constructor(endpoint: string, options?: TestClientOptions) {
    this.#context = createTestClientContext(endpoint, options);
  }
  async create(widget: Widget, options?: CreateOptions) {
    return create(this.#context, widget, options);
  }
}
```
